/**
* Copyright 2007 - 2011 Skyway Software, Inc.
*/
package org.skyway.spring.util.annotation;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

@Target(ElementType.TYPE)
@Retention(RetentionPolicy.SOURCE)
@Documented
/**
 * Annotation for maintaining a link between a class and its JUnit test class.  Since there is no implicit link to a JUnit test
 * class from the source class, this link helps to maintain that link.  The single value of this annotation is the reference to the test class.
 * By maintaining the annotation in this way, it will participate in refactoring of both the base class and its JUnit.  This annotation has a
 * retention policy only of {@link RetentionPolicy.SOURCE}, indicating that it will not be present in the compiled class.  
 */
public @interface JUnitReference {

	Class<?> value();

}
