/**
* Copyright 2007 - 2011 Skyway Software, Inc.
*/
package org.skyway.spring.util.dao.query;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.springframework.jdbc.core.PreparedStatementCreator;
import org.springframework.jdbc.core.SqlProvider;

public class FixedPreparedStatementCreator implements PreparedStatementCreator, SqlProvider {

	private Object[] parameters;
	private int startResult;
	private int maxResults;
	private String sql;
	
	public FixedPreparedStatementCreator(String sql, int startResult, int maxResults){
		this.sql = sql;
		this.startResult = startResult;
		this.maxResults = maxResults;
	}
	
	public String getSql(){
		return sql;
	}

	public void prepare(Object... parameters){
		this.parameters = parameters;
	}
	
	public PreparedStatement createPreparedStatement(Connection connection) throws SQLException{
		int resultSetConcurrency = ResultSet.CONCUR_READ_ONLY;
		int resultSetType = ResultSet.TYPE_FORWARD_ONLY;
		PreparedStatement statement;
		
		if (sql == null || sql.length() == 0){
			throw new RuntimeException("Query is empty.");
		}
		
		if (startResult > 0){
			resultSetType = ResultSet.TYPE_SCROLL_INSENSITIVE;
		}
		
		statement = connection.prepareStatement(sql, resultSetType, resultSetConcurrency);
		
		if (maxResults >= 0){
			if (startResult > 0){
				maxResults += startResult;
			}
			
			statement.setMaxRows(maxResults);
		}
		
		if (parameters != null){
			for (int index = 0; index < parameters.length; index++){
				statement.setObject(index + 1, parameters[index]);
			}
		}
		
		return statement;
	}
}
